==> kubernetes-model-apps-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StatefulSetSpecBuilder extends io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluentImpl<io.fabric8.kubernetes.api.model.apps.StatefulSetSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apps.StatefulSetSpec,io.fabric8.kubernetes.api.model.apps.StatefulSetSpecBuilder>{
  public StatefulSetSpecBuilder() {
    this(false);
  }
  public StatefulSetSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new StatefulSetSpec(), validationEnabled);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StatefulSetSpec(), validationEnabled);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance) {
    this(fluent, instance, false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPodManagementPolicy(instance.getPodManagementPolicy()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withRevisionHistoryLimit(instance.getRevisionHistoryLimit()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withServiceName(instance.getServiceName()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withUpdateStrategy(instance.getUpdateStrategy()); 
    fluent.withVolumeClaimTemplates(instance.getVolumeClaimTemplates()); 
    this.validationEnabled = validationEnabled; 
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance) {
    this(instance,false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPodManagementPolicy(instance.getPodManagementPolicy()); 
    this.withReplicas(instance.getReplicas()); 
    this.withRevisionHistoryLimit(instance.getRevisionHistoryLimit()); 
    this.withSelector(instance.getSelector()); 
    this.withServiceName(instance.getServiceName()); 
    this.withTemplate(instance.getTemplate()); 
    this.withUpdateStrategy(instance.getUpdateStrategy()); 
    this.withVolumeClaimTemplates(instance.getVolumeClaimTemplates()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apps.StatefulSetSpec build() {
    StatefulSetSpec buildable = new StatefulSetSpec(fluent.getPodManagementPolicy(),fluent.getReplicas(),fluent.getRevisionHistoryLimit(),fluent.getSelector(),fluent.getServiceName(),fluent.getTemplate(),fluent.getUpdateStrategy(),fluent.getVolumeClaimTemplates());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetSpecBuilder that = (StatefulSetSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apps-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StatefulSetSpecBuilder extends io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluentImpl<io.fabric8.kubernetes.api.model.apps.StatefulSetSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apps.StatefulSetSpec,io.fabric8.kubernetes.api.model.apps.StatefulSetSpecBuilder>{
  public StatefulSetSpecBuilder() {
    this(false);
  }
  public StatefulSetSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new StatefulSetSpec(), validationEnabled);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StatefulSetSpec(), validationEnabled);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance) {
    this(fluent, instance, false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMinReadySeconds(instance.getMinReadySeconds()); 
    fluent.withPodManagementPolicy(instance.getPodManagementPolicy()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withRevisionHistoryLimit(instance.getRevisionHistoryLimit()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withServiceName(instance.getServiceName()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withUpdateStrategy(instance.getUpdateStrategy()); 
    fluent.withVolumeClaimTemplates(instance.getVolumeClaimTemplates()); 
    this.validationEnabled = validationEnabled; 
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance) {
    this(instance,false);
  }
  public StatefulSetSpecBuilder(io.fabric8.kubernetes.api.model.apps.StatefulSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMinReadySeconds(instance.getMinReadySeconds()); 
    this.withPodManagementPolicy(instance.getPodManagementPolicy()); 
    this.withReplicas(instance.getReplicas()); 
    this.withRevisionHistoryLimit(instance.getRevisionHistoryLimit()); 
    this.withSelector(instance.getSelector()); 
    this.withServiceName(instance.getServiceName()); 
    this.withTemplate(instance.getTemplate()); 
    this.withUpdateStrategy(instance.getUpdateStrategy()); 
    this.withVolumeClaimTemplates(instance.getVolumeClaimTemplates()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apps.StatefulSetSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apps.StatefulSetSpec build() {
    StatefulSetSpec buildable = new StatefulSetSpec(fluent.getMinReadySeconds(),fluent.getPodManagementPolicy(),fluent.getReplicas(),fluent.getRevisionHistoryLimit(),fluent.getSelector(),fluent.getServiceName(),fluent.getTemplate(),fluent.getUpdateStrategy(),fluent.getVolumeClaimTemplates());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetSpecBuilder that = (StatefulSetSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
